==> dkimverified-1.2.tar: dkimverified/dkimverified.php <==
<?php

/**
 * If a message has successfully passed spamassassin's dkim verification, show a green icon
 * icon describing status of verification
 * Icons from http://trac.roundcube.net/ticket/1484547
 *
 * @version 1.2
 * @author Julien Vehent
 * based on 
 * @author Vladimir Mach
 * @mail wladik@gmail.com
 * @website http://www.wladik.net
 *
 * Changelog:
 *	20100114 - changed the checked header to match x-spam-status: DKIM_VERIFIED (j. vehent)
 *	20090920 - fixed space in matching status (thanks Pim Pronk for suggestion)
 */
class dkimverified extends rcube_plugin
{
	public $task = 'mail';
	function init()
	{
		$rcmail = rcmail::get_instance();
		if ($rcmail->action == 'show' || $rcmail->action == 'preview') {
			$this->add_hook('imap_init', array($this, 'imap_init'));
			$this->add_hook('message_headers_output', array($this, 'message_headers'));
		} else if ($rcmail->action == '') {
				// with enabled_caching we're fetching additional headers before show/preview
				$this->add_hook('imap_init', array($this, 'imap_init'));
			}
	}
	
	function imap_init($p)
	{
		$rcmail = rcmail::get_instance();
		$p['fetch_headers'] = trim($p['fetch_headers'].' ' . strtoupper('X-Spam-Status'));
		return $p;
	}
	
	function message_headers($p)
	{
		$this->add_texts('localization');
		if($p['headers']->others['x-spam-status']) {
			$results = $p['headers']->others['x-spam-status'];
			if(preg_match("/DKIM_VERIFIED/", $results, $m)) {
				$status = 'pass';
			}
			if($status == 'pass') {
				$p['output']['from']['value'] = '<img src="plugins/dkimverified/images/verified_sender.png" alt="'.$this->gettext('verifiedsender').'" title="'.$this->gettext('verifiedsender').'" /> ' . $p['output']['from']['value'];
			} else $p['output']['from']['value'] = '<img src="plugins/dkimverified/images/invalid_signature.png" alt="'.$this->gettext('invalidsignature').'" title="'.$this->gettext('invalidsignature').'" /> ' . $p['output']['from']['value'];
		}
		return $p;
	}
}

==> dkimverified-1.3.tar: dkimverified/dkimverified.php <==
<?php

/**
 * If a message has successfully passed spamassassin's dkim verification, show a green icon
 * icon describing status of verification
 * Icons from http://trac.roundcube.net/ticket/1484547
 *
 * @version 1.2
 * @author Julien Vehent
 * based on 
 * @author Vladimir Mach
 * @mail wladik@gmail.com
 * @website http://www.wladik.net
 *
 * Changelog:
 *	20100114 - changed the checked header to match x-spam-status: DKIM_VERIFIED (j. vehent)
 *	20090920 - fixed space in matching status (thanks Pim Pronk for suggestion)
 */
class dkimverified extends rcube_plugin
{
	public $task = 'mail';
	function init()
	{
		$rcmail = rcmail::get_instance();
		if ($rcmail->action == 'show' || $rcmail->action == 'preview') {
			$this->add_hook('imap_init', array($this, 'imap_init'));
			$this->add_hook('message_headers_output', array($this, 'message_headers'));
		} else if ($rcmail->action == '') {
				// with enabled_caching we're fetching additional headers before show/preview
				$this->add_hook('imap_init', array($this, 'imap_init'));
			}
	}
	
	function imap_init($p)
	{
		$rcmail = rcmail::get_instance();
		$p['fetch_headers'] = trim($p['fetch_headers'].' ' . strtoupper('X-Spam-Status'));
		return $p;
	}
	
	function message_headers($p)
	{
		$this->add_texts('localization');
		if($p['headers']->others['x-spam-status']) {
			$results = $p['headers']->others['x-spam-status'];
			//has a verified signature
			if(preg_match("/DKIM_VERIFIED/", $results)||preg_match("/DK_VERIFIED/", $results)) {
				$status = 'pass';
			}
			//has a signature but not verified
			elseif(preg_match("/DKIM_SIGNED/", $results)||preg_match("/DK_SIGNED/", $results)){
				$status = 'fail';
			}
			//has no DKIM or DK information
			else
			{
				$status = 'none';
			}
			if($status == 'pass') {
				$p['output']['from']['value'] = '<img src="plugins/dkimverified/images/verified_sender.png" alt="'.$this->gettext('verifiedsender').'" title="'.$this->gettext('verifiedsender').'" /> ' . $p['output']['from']['value'];
			} elseif($status == 'fail'){
				$p['output']['from']['value'] = '<img src="plugins/dkimverified/images/invalid_signature.png" alt="'.$this->gettext('invalidsignature').'" title="'.$this->gettext('invalidsignature').'" /> ' . $p['output']['from']['value'];
			} else {
				$p['output']['from']['value'] = '<img src="plugins/dkimverified/images/unknown_signature.png" alt="'.$this->gettext('unknownsignature').'" title="'.$this->gettext('unknownsignature').'" /> ' . $p['output'    ]['from']['value'];
			}
		}
		return $p;
	}
}
